pub struct AnalyticsService { /* private fields */ }Expand description
Implements a client for the Vertex AI Search for commerce API.
Example
use google_cloud_lro::Poller;
let client = AnalyticsService::builder().build().await?;
let response = client.export_analytics_metrics()
/* set fields */
.poller().until_done().await?;
println!("response {:?}", response);Service Description
Service for managing & accessing retail search business metric. Retail recommendation business metric is currently not available.
Configuration
To configure AnalyticsService use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://retail.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
AnalyticsService holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap AnalyticsService in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl AnalyticsService
impl AnalyticsService
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for AnalyticsService.
let client = AnalyticsService::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: AnalyticsService + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: AnalyticsService + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn export_analytics_metrics(&self) -> ExportAnalyticsMetrics
pub fn export_analytics_metrics(&self) -> ExportAnalyticsMetrics
Exports analytics metrics.
Operation.response is of type ExportAnalyticsMetricsResponse.
Operation.metadata is of type ExportMetadata.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_retail_v2::Result;
async fn sample(
client: &AnalyticsService
) -> Result<()> {
let response = client.export_analytics_metrics()
/* set fields */
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_retail_v2::Result;
async fn sample(
client: &AnalyticsService
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_retail_v2::Result;
async fn sample(
client: &AnalyticsService
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Trait Implementations
Sourceimpl Clone for AnalyticsService
impl Clone for AnalyticsService
Sourcefn clone(&self) -> AnalyticsService
fn clone(&self) -> AnalyticsService
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more