#[non_exhaustive]pub enum ExactSearchableOption {
Unspecified,
ExactSearchableEnabled,
ExactSearchableDisabled,
UnknownValue(UnknownValue),
}Expand description
The status of the exact-searchable option of a catalog attribute.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unspecified
Value used when unset.
ExactSearchableEnabled
Exact searchable option enabled for an attribute.
ExactSearchableDisabled
Exact searchable option disabled for an attribute.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using ExactSearchableOption::value or ExactSearchableOption::name.
Implementations