#[non_exhaustive]pub enum AttributeConfigLevel {
Unspecified,
ProductLevelAttributeConfig,
CatalogLevelAttributeConfig,
UnknownValue(UnknownValue),
}Expand description
At which level we offer configuration for attributes.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Value used when unset. In this case, server behavior defaults to CATALOG_LEVEL_ATTRIBUTE_CONFIG.
ProductLevelAttributeConfig
At this level, we honor the attribute configurations set in Product.attributes.
CatalogLevelAttributeConfig
At this level, we honor the attribute configurations set in
CatalogConfig.attribute_configs.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using AttributeConfigLevel::value or AttributeConfigLevel::name.
Implementations