#[non_exhaustive]pub enum SearchSolutionUseCase {
Unspecified,
Search,
Browse,
UnknownValue(UnknownValue),
}Expand description
The use case of Cloud Retail Search.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unspecified
The value when it’s unspecified. In this case, server behavior defaults to SEARCH_SOLUTION_USE_CASE_SEARCH.
Search
Search use case. Expects the traffic has a non-empty query.
Browse
Browse use case. Expects the traffic has an empty query.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using SearchSolutionUseCase::value or SearchSolutionUseCase::name.
Implementations