AddLocalInventoriesRequest

Struct AddLocalInventoriesRequest 

#[non_exhaustive]
pub struct AddLocalInventoriesRequest { pub product: String, pub local_inventories: Vec<LocalInventory>, pub add_mask: Option<FieldMask>, pub add_time: Option<Timestamp>, pub allow_missing: bool, /* private fields */ }
Request message for ProductService.AddLocalInventories method.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
product: String

Required. Full resource name of Product, such as projects/*/locations/global/catalogs/default_catalog/branches/default_branch/products/some_product_id.

If the caller does not have permission to access the Product, regardless of whether or not it exists, a PERMISSION_DENIED error is returned.

local_inventories: Vec<LocalInventory>

Required. A list of inventory information at difference places. Each place is identified by its place ID. At most 3000 inventories are allowed per request.

add_mask: Option<FieldMask>

Indicates which inventory fields in the provided list of LocalInventory to update. The field is updated to the provided value.

If a field is set while the place does not have a previous local inventory, the local inventory at that store is created.

If a field is set while the value of that field is not provided, the original field value, if it exists, is deleted.

If the mask is not set or set with empty paths, all inventory fields will be updated.

If an unsupported or unknown field is provided, an INVALID_ARGUMENT error is returned and the entire update will be ignored.

add_time: Option<Timestamp>

The time when the inventory updates are issued. Used to prevent out-of-order updates on local inventory fields. If not provided, the internal system time will be used.

allow_missing: bool

If set to true, and the Product is not found, the local inventory will still be processed and retained for at most 1 day and processed once the Product is created. If set to false, a NOT_FOUND error is returned if the Product is not found.

Implementations

Source

impl AddLocalInventoriesRequest

pub fn new() -> Self

Creates a new default instance.

pub fn set_product<T: Into<String>>(self, v: T) -> Self

Sets the value of product.

Example
let x = AddLocalInventoriesRequest::new().set_product("example");
pub fn set_local_inventories<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<LocalInventory>,

Sets the value of local_inventories.

Example
use google_cloud_retail_v2::model::LocalInventory;
let x = AddLocalInventoriesRequest::new()
    .set_local_inventories([
        LocalInventory::default()/* use setters */,
        LocalInventory::default()/* use (different) setters */,
    ]);
pub fn set_add_mask<T>(self, v: T) -> Self
where T: Into<FieldMask>,

Sets the value of add_mask.

Example
use wkt::FieldMask;
let x = AddLocalInventoriesRequest::new().set_add_mask(FieldMask::default()/* use setters */);
pub fn set_or_clear_add_mask<T>(self, v: Option<T>) -> Self
where T: Into<FieldMask>,

Sets or clears the value of add_mask.

Example
use wkt::FieldMask;
let x = AddLocalInventoriesRequest::new().set_or_clear_add_mask(Some(FieldMask::default()/* use setters */));
let x = AddLocalInventoriesRequest::new().set_or_clear_add_mask(None::<FieldMask>);
pub fn set_add_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of add_time.

Example
use wkt::Timestamp;
let x = AddLocalInventoriesRequest::new().set_add_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_add_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of add_time.

Example
use wkt::Timestamp;
let x = AddLocalInventoriesRequest::new().set_or_clear_add_time(Some(Timestamp::default()/* use setters */));
let x = AddLocalInventoriesRequest::new().set_or_clear_add_time(None::<Timestamp>);
pub fn set_allow_missing<T: Into<bool>>(self, v: T) -> Self

Sets the value of allow_missing.

Example
let x = AddLocalInventoriesRequest::new().set_allow_missing(true);