ConversationalSearchResponse

Struct ConversationalSearchResponse 

#[non_exhaustive]
pub struct ConversationalSearchResponse { pub user_query_types: Vec<String>, pub conversational_text_response: String, pub followup_question: Option<FollowupQuestion>, pub conversation_id: String, pub refined_search: Vec<RefinedSearch>, pub conversational_filtering_result: Option<ConversationalFilteringResult>, pub state: State, /* private fields */ }
Response message for [ConversationalSearchService.ConversationalSearch][google.cloud.retail.v2.ConversationalSearchService.ConversationalSearch] method.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
user_query_types: Vec<String>

The types Retail classifies the search query as.

Supported values are:

  • “ORDER_SUPPORT”
  • “SIMPLE_PRODUCT_SEARCH”
  • “INTENT_REFINEMENT”
  • “PRODUCT_DETAILS”
  • “PRODUCT_COMPARISON”
  • “DEALS_AND_COUPONS”
  • “STORE_RELEVANT”
  • “BLOCKLISTED”
  • “BEST_PRODUCT”
  • “RETAIL_SUPPORT”
  • “DISABLED”
conversational_text_response: String

The conversational answer-based text response generated by the Server.

followup_question: Option<FollowupQuestion>

The conversational followup question generated for Intent refinement.

conversation_id: String

Conversation UUID. This field will be stored in client side storage to maintain the conversation session with server and will be used for next search request’s ConversationalSearchRequest.conversation_id to restore conversation state in server.

refined_search: Vec<RefinedSearch>

The proposed refined search queries. They can be used to fetch the relevant search results. When using CONVERSATIONAL_FILTER_ONLY mode, the refined_query from search response will be populated here.

conversational_filtering_result: Option<ConversationalFilteringResult>

This field specifies all related information that is needed on client side for UI rendering of conversational filtering search.

state: State

Output only. The state of the response generation.

Implementations

Source

impl ConversationalSearchResponse

pub fn new() -> Self

Creates a new default instance.

pub fn set_user_query_types<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of user_query_types.

Example
let x = ConversationalSearchResponse::new().set_user_query_types(["a", "b", "c"]);
pub fn set_conversational_text_response<T: Into<String>>(self, v: T) -> Self

Sets the value of conversational_text_response.

Example
let x = ConversationalSearchResponse::new().set_conversational_text_response("example");
pub fn set_followup_question<T>(self, v: T) -> Self

Sets the value of followup_question.

Example
use google_cloud_retail_v2::model::conversational_search_response::FollowupQuestion;
let x = ConversationalSearchResponse::new().set_followup_question(FollowupQuestion::default()/* use setters */);
pub fn set_or_clear_followup_question<T>(self, v: Option<T>) -> Self

Sets or clears the value of followup_question.

Example
use google_cloud_retail_v2::model::conversational_search_response::FollowupQuestion;
let x = ConversationalSearchResponse::new().set_or_clear_followup_question(Some(FollowupQuestion::default()/* use setters */));
let x = ConversationalSearchResponse::new().set_or_clear_followup_question(None::<FollowupQuestion>);
pub fn set_conversation_id<T: Into<String>>(self, v: T) -> Self

Sets the value of conversation_id.

Example
let x = ConversationalSearchResponse::new().set_conversation_id("example");

Sets the value of refined_search.

Example
use google_cloud_retail_v2::model::conversational_search_response::RefinedSearch;
let x = ConversationalSearchResponse::new()
    .set_refined_search([
        RefinedSearch::default()/* use setters */,
        RefinedSearch::default()/* use (different) setters */,
    ]);
pub fn set_conversational_filtering_result<T>(self, v: T) -> Self

Sets the value of conversational_filtering_result.

Example
use google_cloud_retail_v2::model::conversational_search_response::ConversationalFilteringResult;
let x = ConversationalSearchResponse::new().set_conversational_filtering_result(ConversationalFilteringResult::default()/* use setters */);
pub fn set_or_clear_conversational_filtering_result<T>( self, v: Option<T>, ) -> Self

Sets or clears the value of conversational_filtering_result.

Example
use google_cloud_retail_v2::model::conversational_search_response::ConversationalFilteringResult;
let x = ConversationalSearchResponse::new().set_or_clear_conversational_filtering_result(Some(ConversationalFilteringResult::default()/* use setters */));
let x = ConversationalSearchResponse::new().set_or_clear_conversational_filtering_result(None::<ConversationalFilteringResult>);
pub fn set_state<T: Into<State>>(self, v: T) -> Self

Sets the value of state.

Example
use google_cloud_retail_v2::model::conversational_search_response::State;
let x0 = ConversationalSearchResponse::new().set_state(State::Streaming);
let x1 = ConversationalSearchResponse::new().set_state(State::Succeeded);