#[non_exhaustive]pub struct ExportAnalyticsMetricsRequest {
pub catalog: String,
pub output_config: Option<OutputConfig>,
pub filter: String,
/* private fields */
}Expand description
Request message for the ExportAnalyticsMetrics method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.catalog: StringRequired. Full resource name of the parent catalog.
Expected format: projects/*/locations/*/catalogs/*
output_config: Option<OutputConfig>Required. The output location of the data.
filter: StringA filtering expression to specify restrictions on returned metrics. The expression is a sequence of terms. Each term applies a restriction to the returned metrics. Use this expression to restrict results to a specific time range.
Currently we expect only one types of fields:
timestamp: This can be specified twice, once with a less than operator and once with a greater than operator. Thetimestamprestriction should result in one, contiguous, valid,timestamprange.
Some examples of valid filters expressions:
- Example 1:
timestamp > "2012-04-23T18:25:43.511Z" timestamp < "2012-04-23T18:30:43.511Z" - Example 2:
timestamp > "2012-04-23T18:25:43.511Z"
Implementations
Sourceimpl ExportAnalyticsMetricsRequest
impl ExportAnalyticsMetricsRequest
Sourcepub fn set_catalog<T: Into<String>>(self, v: T) -> Self
pub fn set_catalog<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_output_config<T>(self, v: T) -> Selfwhere
T: Into<OutputConfig>,
pub fn set_output_config<T>(self, v: T) -> Selfwhere
T: Into<OutputConfig>,
Sets the value of output_config.
Example
ⓘ
use google_cloud_retail_v2::model::OutputConfig;
let x = ExportAnalyticsMetricsRequest::new().set_output_config(OutputConfig::default()/* use setters */);Sourcepub fn set_or_clear_output_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<OutputConfig>,
pub fn set_or_clear_output_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<OutputConfig>,
Sets or clears the value of output_config.
Example
ⓘ
use google_cloud_retail_v2::model::OutputConfig;
let x = ExportAnalyticsMetricsRequest::new().set_or_clear_output_config(Some(OutputConfig::default()/* use setters */));
let x = ExportAnalyticsMetricsRequest::new().set_or_clear_output_config(None::<OutputConfig>);Trait Implementations
Sourceimpl Clone for ExportAnalyticsMetricsRequest
impl Clone for ExportAnalyticsMetricsRequest
Sourcefn clone(&self) -> ExportAnalyticsMetricsRequest
fn clone(&self) -> ExportAnalyticsMetricsRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ExportAnalyticsMetricsRequest
impl Default for ExportAnalyticsMetricsRequest
Sourcefn default() -> ExportAnalyticsMetricsRequest
fn default() -> ExportAnalyticsMetricsRequest
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ExportAnalyticsMetricsRequest
impl PartialEq for ExportAnalyticsMetricsRequest
Sourcefn eq(&self, other: &ExportAnalyticsMetricsRequest) -> bool
fn eq(&self, other: &ExportAnalyticsMetricsRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ExportAnalyticsMetricsRequest