#[non_exhaustive]pub struct ExportAnalyticsMetricsResponse {
pub error_samples: Vec<Status>,
pub errors_config: Option<ExportErrorsConfig>,
pub output_result: Option<OutputResult>,
/* private fields */
}Expand description
Response of the ExportAnalyticsMetricsRequest. If the long running operation was successful, then this message is returned by the google.longrunning.Operations.response field if the operation was successful.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.error_samples: Vec<Status>A sample of errors encountered while processing the request.
errors_config: Option<ExportErrorsConfig>This field is never set.
output_result: Option<OutputResult>Output result indicating where the data were exported to.
Implementations
Sourceimpl ExportAnalyticsMetricsResponse
impl ExportAnalyticsMetricsResponse
Sourcepub fn set_error_samples<T, V>(self, v: T) -> Self
pub fn set_error_samples<T, V>(self, v: T) -> Self
Sets the value of error_samples.
Example
ⓘ
use google_cloud_rpc::model::Status;
let x = ExportAnalyticsMetricsResponse::new()
.set_error_samples([
Status::default()/* use setters */,
Status::default()/* use (different) setters */,
]);Sourcepub fn set_errors_config<T>(self, v: T) -> Selfwhere
T: Into<ExportErrorsConfig>,
pub fn set_errors_config<T>(self, v: T) -> Selfwhere
T: Into<ExportErrorsConfig>,
Sets the value of errors_config.
Example
ⓘ
use google_cloud_retail_v2::model::ExportErrorsConfig;
let x = ExportAnalyticsMetricsResponse::new().set_errors_config(ExportErrorsConfig::default()/* use setters */);Sourcepub fn set_or_clear_errors_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<ExportErrorsConfig>,
pub fn set_or_clear_errors_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<ExportErrorsConfig>,
Sets or clears the value of errors_config.
Example
ⓘ
use google_cloud_retail_v2::model::ExportErrorsConfig;
let x = ExportAnalyticsMetricsResponse::new().set_or_clear_errors_config(Some(ExportErrorsConfig::default()/* use setters */));
let x = ExportAnalyticsMetricsResponse::new().set_or_clear_errors_config(None::<ExportErrorsConfig>);Sourcepub fn set_output_result<T>(self, v: T) -> Selfwhere
T: Into<OutputResult>,
pub fn set_output_result<T>(self, v: T) -> Selfwhere
T: Into<OutputResult>,
Sets the value of output_result.
Example
ⓘ
use google_cloud_retail_v2::model::OutputResult;
let x = ExportAnalyticsMetricsResponse::new().set_output_result(OutputResult::default()/* use setters */);Sourcepub fn set_or_clear_output_result<T>(self, v: Option<T>) -> Selfwhere
T: Into<OutputResult>,
pub fn set_or_clear_output_result<T>(self, v: Option<T>) -> Selfwhere
T: Into<OutputResult>,
Sets or clears the value of output_result.
Example
ⓘ
use google_cloud_retail_v2::model::OutputResult;
let x = ExportAnalyticsMetricsResponse::new().set_or_clear_output_result(Some(OutputResult::default()/* use setters */));
let x = ExportAnalyticsMetricsResponse::new().set_or_clear_output_result(None::<OutputResult>);Trait Implementations
Sourceimpl Clone for ExportAnalyticsMetricsResponse
impl Clone for ExportAnalyticsMetricsResponse
Sourcefn clone(&self) -> ExportAnalyticsMetricsResponse
fn clone(&self) -> ExportAnalyticsMetricsResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ExportAnalyticsMetricsResponse
impl Default for ExportAnalyticsMetricsResponse
Sourcefn default() -> ExportAnalyticsMetricsResponse
fn default() -> ExportAnalyticsMetricsResponse
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ExportAnalyticsMetricsResponse
impl PartialEq for ExportAnalyticsMetricsResponse
Sourcefn eq(&self, other: &ExportAnalyticsMetricsResponse) -> bool
fn eq(&self, other: &ExportAnalyticsMetricsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ExportAnalyticsMetricsResponse