#[non_exhaustive]pub struct ExportErrorsConfig {
pub destination: Option<Destination>,
/* private fields */
}Expand description
Configuration of destination for Export related errors.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.destination: Option<Destination>Required. Errors destination.
Implementations
Sourceimpl ExportErrorsConfig
impl ExportErrorsConfig
Sourcepub fn set_destination<T: Into<Option<Destination>>>(self, v: T) -> Self
pub fn set_destination<T: Into<Option<Destination>>>(self, v: T) -> Self
Sets the value of destination.
Note that all the setters affecting destination are mutually
exclusive.
Example
ⓘ
use google_cloud_retail_v2::model::export_errors_config::Destination;
let x = ExportErrorsConfig::new().set_destination(Some(Destination::GcsPrefix("example".to_string())));Sourcepub fn gcs_prefix(&self) -> Option<&String>
pub fn gcs_prefix(&self) -> Option<&String>
The value of destination
if it holds a GcsPrefix, None if the field is not set or
holds a different branch.
Sourcepub fn set_gcs_prefix<T: Into<String>>(self, v: T) -> Self
pub fn set_gcs_prefix<T: Into<String>>(self, v: T) -> Self
Sets the value of destination
to hold a GcsPrefix.
Note that all the setters affecting destination are
mutually exclusive.
Example
ⓘ
let x = ExportErrorsConfig::new().set_gcs_prefix("example");
assert!(x.gcs_prefix().is_some());Trait Implementations
Sourceimpl Clone for ExportErrorsConfig
impl Clone for ExportErrorsConfig
Sourcefn clone(&self) -> ExportErrorsConfig
fn clone(&self) -> ExportErrorsConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExportErrorsConfig
impl Debug for ExportErrorsConfig
Sourceimpl Default for ExportErrorsConfig
impl Default for ExportErrorsConfig
Sourcefn default() -> ExportErrorsConfig
fn default() -> ExportErrorsConfig
Returns the “default value” for a type. Read more
Sourceimpl Message for ExportErrorsConfig
impl Message for ExportErrorsConfig
Sourceimpl PartialEq for ExportErrorsConfig
impl PartialEq for ExportErrorsConfig
impl StructuralPartialEq for ExportErrorsConfig