#[non_exhaustive]pub struct ExportMetadata {
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
/* private fields */
}Expand description
Metadata related to the progress of the Export operation. This is returned by the google.longrunning.Operation.metadata field.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.create_time: Option<Timestamp>Operation create time.
update_time: Option<Timestamp>Operation last update time. If the operation is done, this is also the finish time.
Implementations
Sourceimpl ExportMetadata
impl ExportMetadata
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
ⓘ
use wkt::Timestamp;
let x = ExportMetadata::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
ⓘ
use wkt::Timestamp;
let x = ExportMetadata::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = ExportMetadata::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
ⓘ
use wkt::Timestamp;
let x = ExportMetadata::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
ⓘ
use wkt::Timestamp;
let x = ExportMetadata::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = ExportMetadata::new().set_or_clear_update_time(None::<Timestamp>);Trait Implementations
Sourceimpl Clone for ExportMetadata
impl Clone for ExportMetadata
Sourcefn clone(&self) -> ExportMetadata
fn clone(&self) -> ExportMetadata
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExportMetadata
impl Debug for ExportMetadata
Sourceimpl Default for ExportMetadata
impl Default for ExportMetadata
Sourcefn default() -> ExportMetadata
fn default() -> ExportMetadata
Returns the “default value” for a type. Read more
Sourceimpl Message for ExportMetadata
impl Message for ExportMetadata
Sourceimpl PartialEq for ExportMetadata
impl PartialEq for ExportMetadata
impl StructuralPartialEq for ExportMetadata