#[non_exhaustive]pub struct GcsSource {
pub input_uris: Vec<String>,
pub data_schema: String,
/* private fields */
}Expand description
Google Cloud Storage location for input content.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.input_uris: Vec<String>Required. Google Cloud Storage URIs to input files. URI can be up to
2000 characters long. URIs can match the full object path (for example,
gs://bucket/directory/object.json) or a pattern matching one or more
files, such as gs://bucket/directory/*.json. A request can
contain at most 100 files, and each file can be up to 2 GB. See
Importing product
information
for the expected file format and setup instructions.
data_schema: StringThe schema to use when parsing the data from the source.
Supported values for product imports:
product(default): One JSON Product per line. Each product must have a valid Product.id.product_merchant_center: See Importing catalog data from Merchant Center.
Supported values for user events imports:
user_event(default): One JSON UserEvent per line.user_event_ga360: Using https://support.google.com/analytics/answer/3437719.
Supported values for control imports:
control(default): One JSON Control per line.
Supported values for catalog attribute imports:
catalog_attribute(default): One CSV CatalogAttribute per line.
Implementations
Sourceimpl GcsSource
impl GcsSource
Sourcepub fn set_input_uris<T, V>(self, v: T) -> Self
pub fn set_input_uris<T, V>(self, v: T) -> Self
Sourcepub fn set_data_schema<T: Into<String>>(self, v: T) -> Self
pub fn set_data_schema<T: Into<String>>(self, v: T) -> Self