#[non_exhaustive]pub struct GetDefaultBranchResponse {
pub branch: String,
pub set_time: Option<Timestamp>,
pub note: String,
/* private fields */
}Expand description
Response message of CatalogService.GetDefaultBranch.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.branch: StringFull resource name of the branch id currently set as default branch.
set_time: Option<Timestamp>The time when this branch is set to default.
note: StringThis corresponds to SetDefaultBranchRequest.note field, when this branch was set as default.
Implementations
Sourceimpl GetDefaultBranchResponse
impl GetDefaultBranchResponse
Sourcepub fn set_branch<T: Into<String>>(self, v: T) -> Self
pub fn set_branch<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_set_time<T>(self, v: T) -> Self
pub fn set_set_time<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_set_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_set_time<T>(self, v: Option<T>) -> Self