Image

Struct Image 

#[non_exhaustive]
pub struct Image { pub uri: String, pub height: i32, pub width: i32, /* private fields */ }
Product image. Recommendations AI and Retail Search use product images to improve prediction and search results. Product images can be returned in results, and are shown in prediction or search previews in the console. Please try to provide correct product images and avoid using images with size too small.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
uri: String

Required. URI of the image.

This field must be a valid UTF-8 encoded URI with a length limit of 5,000 characters. Otherwise, an INVALID_ARGUMENT error is returned.

Google Merchant Center property image_link. Schema.org property Product.image.

height: i32

Height of the image in number of pixels.

This field must be nonnegative. Otherwise, an INVALID_ARGUMENT error is returned.

width: i32

Width of the image in number of pixels.

This field must be nonnegative. Otherwise, an INVALID_ARGUMENT error is returned.

Implementations

Source

impl Image

pub fn new() -> Self

Creates a new default instance.

pub fn set_uri<T: Into<String>>(self, v: T) -> Self

Sets the value of uri.

Example
let x = Image::new().set_uri("example");
pub fn set_height<T: Into<i32>>(self, v: T) -> Self

Sets the value of height.

Example
let x = Image::new().set_height(42);
pub fn set_width<T: Into<i32>>(self, v: T) -> Self

Sets the value of width.

Example
let x = Image::new().set_width(42);