#[non_exhaustive]pub struct ImportCompletionDataResponse {
pub error_samples: Vec<Status>,
/* private fields */
}Expand description
Response of the ImportCompletionDataRequest. If the long running operation is done, this message is returned by the google.longrunning.Operations.response field if the operation is successful.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.error_samples: Vec<Status>A sample of errors encountered while processing the request.
Implementations
Sourceimpl ImportCompletionDataResponse
impl ImportCompletionDataResponse
pub fn new() -> Self
Sourcepub fn set_error_samples<T, V>(self, v: T) -> Self
pub fn set_error_samples<T, V>(self, v: T) -> Self
Sets the value of error_samples.
Example
ⓘ
use google_cloud_rpc::model::Status;
let x = ImportCompletionDataResponse::new()
.set_error_samples([
Status::default()/* use setters */,
Status::default()/* use (different) setters */,
]);Trait Implementations
Sourceimpl Clone for ImportCompletionDataResponse
impl Clone for ImportCompletionDataResponse
Sourcefn clone(&self) -> ImportCompletionDataResponse
fn clone(&self) -> ImportCompletionDataResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ImportCompletionDataResponse
impl Debug for ImportCompletionDataResponse
Sourceimpl Default for ImportCompletionDataResponse
impl Default for ImportCompletionDataResponse
Sourcefn default() -> ImportCompletionDataResponse
fn default() -> ImportCompletionDataResponse
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ImportCompletionDataResponse
impl PartialEq for ImportCompletionDataResponse
Sourcefn eq(&self, other: &ImportCompletionDataResponse) -> bool
fn eq(&self, other: &ImportCompletionDataResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ImportCompletionDataResponse