#[non_exhaustive]pub struct ImportErrorsConfig {
pub destination: Option<Destination>,
/* private fields */
}Expand description
Configuration of destination for Import related errors.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.destination: Option<Destination>Required. Errors destination.
Implementations
Sourceimpl ImportErrorsConfig
impl ImportErrorsConfig
Sourcepub fn set_destination<T: Into<Option<Destination>>>(self, v: T) -> Self
pub fn set_destination<T: Into<Option<Destination>>>(self, v: T) -> Self
Sets the value of destination.
Note that all the setters affecting destination are mutually
exclusive.
Example
ⓘ
use google_cloud_retail_v2::model::import_errors_config::Destination;
let x = ImportErrorsConfig::new().set_destination(Some(Destination::GcsPrefix("example".to_string())));Sourcepub fn gcs_prefix(&self) -> Option<&String>
pub fn gcs_prefix(&self) -> Option<&String>
The value of destination
if it holds a GcsPrefix, None if the field is not set or
holds a different branch.
Sourcepub fn set_gcs_prefix<T: Into<String>>(self, v: T) -> Self
pub fn set_gcs_prefix<T: Into<String>>(self, v: T) -> Self
Sets the value of destination
to hold a GcsPrefix.
Note that all the setters affecting destination are
mutually exclusive.
Example
ⓘ
let x = ImportErrorsConfig::new().set_gcs_prefix("example");
assert!(x.gcs_prefix().is_some());Trait Implementations
Sourceimpl Clone for ImportErrorsConfig
impl Clone for ImportErrorsConfig
Sourcefn clone(&self) -> ImportErrorsConfig
fn clone(&self) -> ImportErrorsConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ImportErrorsConfig
impl Debug for ImportErrorsConfig
Sourceimpl Default for ImportErrorsConfig
impl Default for ImportErrorsConfig
Sourcefn default() -> ImportErrorsConfig
fn default() -> ImportErrorsConfig
Returns the “default value” for a type. Read more
Sourceimpl Message for ImportErrorsConfig
impl Message for ImportErrorsConfig
Sourceimpl PartialEq for ImportErrorsConfig
impl PartialEq for ImportErrorsConfig
impl StructuralPartialEq for ImportErrorsConfig