#[non_exhaustive]pub struct ImportMetadata {
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub success_count: i64,
pub failure_count: i64,
pub request_id: String,
pub notification_pubsub_topic: String,
/* private fields */
}Expand description
Metadata related to the progress of the Import operation. This is returned by the google.longrunning.Operation.metadata field.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.create_time: Option<Timestamp>Operation create time.
update_time: Option<Timestamp>Operation last update time. If the operation is done, this is also the finish time.
success_count: i64Count of entries that were processed successfully.
failure_count: i64Count of entries that encountered errors while processing.
request_id: StringDeprecated. This field is never set.
notification_pubsub_topic: StringPub/Sub topic for receiving notification. If this field is set,
when the import is finished, a notification is sent to
specified Pub/Sub topic. The message data is JSON string of a
Operation.
Format of the Pub/Sub topic is projects/{project}/topics/{topic}.
Implementations
Sourceimpl ImportMetadata
impl ImportMetadata
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = ImportMetadata::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = ImportMetadata::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = ImportMetadata::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = ImportMetadata::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = ImportMetadata::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = ImportMetadata::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_success_count<T: Into<i64>>(self, v: T) -> Self
pub fn set_success_count<T: Into<i64>>(self, v: T) -> Self
Sourcepub fn set_failure_count<T: Into<i64>>(self, v: T) -> Self
pub fn set_failure_count<T: Into<i64>>(self, v: T) -> Self
Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
👎Deprecated
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_notification_pubsub_topic<T: Into<String>>(self, v: T) -> Self
pub fn set_notification_pubsub_topic<T: Into<String>>(self, v: T) -> Self
Sets the value of notification_pubsub_topic.
Example
let x = ImportMetadata::new().set_notification_pubsub_topic("example");Trait Implementations
Sourceimpl Clone for ImportMetadata
impl Clone for ImportMetadata
Sourcefn clone(&self) -> ImportMetadata
fn clone(&self) -> ImportMetadata
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ImportMetadata
impl Debug for ImportMetadata
Sourceimpl Default for ImportMetadata
impl Default for ImportMetadata
Sourcefn default() -> ImportMetadata
fn default() -> ImportMetadata
Sourceimpl Message for ImportMetadata
impl Message for ImportMetadata
Sourceimpl PartialEq for ImportMetadata
impl PartialEq for ImportMetadata
impl StructuralPartialEq for ImportMetadata