#[non_exhaustive]pub struct ImportUserEventsResponse {
pub error_samples: Vec<Status>,
pub errors_config: Option<ImportErrorsConfig>,
pub import_summary: Option<UserEventImportSummary>,
/* private fields */
}Expand description
Response of the ImportUserEventsRequest. If the long running operation was successful, then this message is returned by the google.longrunning.Operations.response field if the operation was successful.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.error_samples: Vec<Status>A sample of errors encountered while processing the request.
errors_config: Option<ImportErrorsConfig>Echoes the destination for the complete errors if this field was set in the request.
import_summary: Option<UserEventImportSummary>Aggregated statistics of user event import status.
Implementations
Sourceimpl ImportUserEventsResponse
impl ImportUserEventsResponse
Sourcepub fn set_error_samples<T, V>(self, v: T) -> Self
pub fn set_error_samples<T, V>(self, v: T) -> Self
Sets the value of error_samples.
Example
ⓘ
use google_cloud_rpc::model::Status;
let x = ImportUserEventsResponse::new()
.set_error_samples([
Status::default()/* use setters */,
Status::default()/* use (different) setters */,
]);Sourcepub fn set_errors_config<T>(self, v: T) -> Selfwhere
T: Into<ImportErrorsConfig>,
pub fn set_errors_config<T>(self, v: T) -> Selfwhere
T: Into<ImportErrorsConfig>,
Sets the value of errors_config.
Example
ⓘ
use google_cloud_retail_v2::model::ImportErrorsConfig;
let x = ImportUserEventsResponse::new().set_errors_config(ImportErrorsConfig::default()/* use setters */);Sourcepub fn set_or_clear_errors_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<ImportErrorsConfig>,
pub fn set_or_clear_errors_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<ImportErrorsConfig>,
Sets or clears the value of errors_config.
Example
ⓘ
use google_cloud_retail_v2::model::ImportErrorsConfig;
let x = ImportUserEventsResponse::new().set_or_clear_errors_config(Some(ImportErrorsConfig::default()/* use setters */));
let x = ImportUserEventsResponse::new().set_or_clear_errors_config(None::<ImportErrorsConfig>);Sourcepub fn set_import_summary<T>(self, v: T) -> Selfwhere
T: Into<UserEventImportSummary>,
pub fn set_import_summary<T>(self, v: T) -> Selfwhere
T: Into<UserEventImportSummary>,
Sets the value of import_summary.
Example
ⓘ
use google_cloud_retail_v2::model::UserEventImportSummary;
let x = ImportUserEventsResponse::new().set_import_summary(UserEventImportSummary::default()/* use setters */);Sourcepub fn set_or_clear_import_summary<T>(self, v: Option<T>) -> Selfwhere
T: Into<UserEventImportSummary>,
pub fn set_or_clear_import_summary<T>(self, v: Option<T>) -> Selfwhere
T: Into<UserEventImportSummary>,
Sets or clears the value of import_summary.
Example
ⓘ
use google_cloud_retail_v2::model::UserEventImportSummary;
let x = ImportUserEventsResponse::new().set_or_clear_import_summary(Some(UserEventImportSummary::default()/* use setters */));
let x = ImportUserEventsResponse::new().set_or_clear_import_summary(None::<UserEventImportSummary>);Trait Implementations
Sourceimpl Clone for ImportUserEventsResponse
impl Clone for ImportUserEventsResponse
Sourcefn clone(&self) -> ImportUserEventsResponse
fn clone(&self) -> ImportUserEventsResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ImportUserEventsResponse
impl Debug for ImportUserEventsResponse
Sourceimpl Default for ImportUserEventsResponse
impl Default for ImportUserEventsResponse
Sourcefn default() -> ImportUserEventsResponse
fn default() -> ImportUserEventsResponse
Returns the “default value” for a type. Read more
Sourceimpl Message for ImportUserEventsResponse
impl Message for ImportUserEventsResponse
Sourceimpl PartialEq for ImportUserEventsResponse
impl PartialEq for ImportUserEventsResponse
impl StructuralPartialEq for ImportUserEventsResponse