ListCatalogsRequest

Struct ListCatalogsRequest 

#[non_exhaustive]
pub struct ListCatalogsRequest { pub parent: String, pub page_size: i32, pub page_token: String, /* private fields */ }
Request for CatalogService.ListCatalogs method.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
parent: String

Required. The account resource name with an associated location.

If the caller does not have permission to list Catalogs under this location, regardless of whether or not this location exists, a PERMISSION_DENIED error is returned.

page_size: i32

Maximum number of Catalogs to return. If unspecified, defaults to 50. The maximum allowed value is 1000. Values above 1000 will be coerced to 1000.

If this field is negative, an INVALID_ARGUMENT is returned.

page_token: String

A page token ListCatalogsResponse.next_page_token, received from a previous CatalogService.ListCatalogs call. Provide this to retrieve the subsequent page.

When paginating, all other parameters provided to CatalogService.ListCatalogs must match the call that provided the page token. Otherwise, an INVALID_ARGUMENT error is returned.

Implementations

Source

impl ListCatalogsRequest

pub fn new() -> Self

Creates a new default instance.

pub fn set_parent<T: Into<String>>(self, v: T) -> Self

Sets the value of parent.

Example
let x = ListCatalogsRequest::new().set_parent("example");
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self

Sets the value of page_size.

Example
let x = ListCatalogsRequest::new().set_page_size(42);
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self

Sets the value of page_token.

Example
let x = ListCatalogsRequest::new().set_page_token("example");