#[non_exhaustive]pub struct OutputResult {
pub bigquery_result: Vec<BigQueryOutputResult>,
pub gcs_result: Vec<GcsOutputResult>,
/* private fields */
}Expand description
Output result that stores the information about where the exported data is stored.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.bigquery_result: Vec<BigQueryOutputResult>The BigQuery location where the result is stored.
gcs_result: Vec<GcsOutputResult>The Google Cloud Storage location where the result is stored.
Implementations
Sourceimpl OutputResult
impl OutputResult
Sourcepub fn set_bigquery_result<T, V>(self, v: T) -> Self
pub fn set_bigquery_result<T, V>(self, v: T) -> Self
Sets the value of bigquery_result.
Example
ⓘ
use google_cloud_retail_v2::model::BigQueryOutputResult;
let x = OutputResult::new()
.set_bigquery_result([
BigQueryOutputResult::default()/* use setters */,
BigQueryOutputResult::default()/* use (different) setters */,
]);Sourcepub fn set_gcs_result<T, V>(self, v: T) -> Self
pub fn set_gcs_result<T, V>(self, v: T) -> Self
Sets the value of gcs_result.
Example
ⓘ
use google_cloud_retail_v2::model::GcsOutputResult;
let x = OutputResult::new()
.set_gcs_result([
GcsOutputResult::default()/* use setters */,
GcsOutputResult::default()/* use (different) setters */,
]);Trait Implementations
Sourceimpl Clone for OutputResult
impl Clone for OutputResult
Sourcefn clone(&self) -> OutputResult
fn clone(&self) -> OutputResult
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OutputResult
impl Debug for OutputResult
Sourceimpl Default for OutputResult
impl Default for OutputResult
Sourcefn default() -> OutputResult
fn default() -> OutputResult
Returns the “default value” for a type. Read more
Sourceimpl Message for OutputResult
impl Message for OutputResult
Sourceimpl PartialEq for OutputResult
impl PartialEq for OutputResult
impl StructuralPartialEq for OutputResult