#[non_exhaustive]pub struct ProductAttributeValue {
pub name: String,
pub value: String,
/* private fields */
}Expand description
Product attribute which structured by an attribute name and value. This
structure is used in conversational search filters and answers. For example,
if we have name=color and value=red, this means that the color is red.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringThe attribute name.
value: StringThe attribute value.
Implementations