#[non_exhaustive]pub struct ProductInputConfig {
pub source: Option<Source>,
/* private fields */
}Expand description
The input config source for products.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.source: Option<Source>Required. The source of the input.
Implementations
Sourceimpl ProductInputConfig
impl ProductInputConfig
Sourcepub fn set_source<T: Into<Option<Source>>>(self, v: T) -> Self
pub fn set_source<T: Into<Option<Source>>>(self, v: T) -> Self
Sets the value of source.
Note that all the setters affecting source are mutually
exclusive.
Example
use google_cloud_retail_v2::model::ProductInlineSource;
let x = ProductInputConfig::new().set_source(Some(
google_cloud_retail_v2::model::product_input_config::Source::ProductInlineSource(ProductInlineSource::default().into())));Sourcepub fn product_inline_source(&self) -> Option<&Box<ProductInlineSource>>
pub fn product_inline_source(&self) -> Option<&Box<ProductInlineSource>>
The value of source
if it holds a ProductInlineSource, None if the field is not set or
holds a different branch.
Sourcepub fn set_product_inline_source<T: Into<Box<ProductInlineSource>>>(
self,
v: T,
) -> Self
pub fn set_product_inline_source<T: Into<Box<ProductInlineSource>>>( self, v: T, ) -> Self
Sets the value of source
to hold a ProductInlineSource.
Note that all the setters affecting source are
mutually exclusive.
Example
use google_cloud_retail_v2::model::ProductInlineSource;
let x = ProductInputConfig::new().set_product_inline_source(ProductInlineSource::default()/* use setters */);
assert!(x.product_inline_source().is_some());
assert!(x.gcs_source().is_none());
assert!(x.big_query_source().is_none());Sourcepub fn gcs_source(&self) -> Option<&Box<GcsSource>>
pub fn gcs_source(&self) -> Option<&Box<GcsSource>>
The value of source
if it holds a GcsSource, None if the field is not set or
holds a different branch.
Sourcepub fn set_gcs_source<T: Into<Box<GcsSource>>>(self, v: T) -> Self
pub fn set_gcs_source<T: Into<Box<GcsSource>>>(self, v: T) -> Self
Sets the value of source
to hold a GcsSource.
Note that all the setters affecting source are
mutually exclusive.
Example
use google_cloud_retail_v2::model::GcsSource;
let x = ProductInputConfig::new().set_gcs_source(GcsSource::default()/* use setters */);
assert!(x.gcs_source().is_some());
assert!(x.product_inline_source().is_none());
assert!(x.big_query_source().is_none());Sourcepub fn big_query_source(&self) -> Option<&Box<BigQuerySource>>
pub fn big_query_source(&self) -> Option<&Box<BigQuerySource>>
The value of source
if it holds a BigQuerySource, None if the field is not set or
holds a different branch.
Sourcepub fn set_big_query_source<T: Into<Box<BigQuerySource>>>(self, v: T) -> Self
pub fn set_big_query_source<T: Into<Box<BigQuerySource>>>(self, v: T) -> Self
Sets the value of source
to hold a BigQuerySource.
Note that all the setters affecting source are
mutually exclusive.
Example
use google_cloud_retail_v2::model::BigQuerySource;
let x = ProductInputConfig::new().set_big_query_source(BigQuerySource::default()/* use setters */);
assert!(x.big_query_source().is_some());
assert!(x.product_inline_source().is_none());
assert!(x.gcs_source().is_none());Trait Implementations
Sourceimpl Clone for ProductInputConfig
impl Clone for ProductInputConfig
Sourcefn clone(&self) -> ProductInputConfig
fn clone(&self) -> ProductInputConfig
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more