ProductLevelConfig

Struct ProductLevelConfig 

#[non_exhaustive]
pub struct ProductLevelConfig { pub ingestion_product_type: String, pub merchant_center_product_id_field: String, /* private fields */ }
Configures what level the product should be uploaded with regards to how users will be send events and how predictions will be made.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
ingestion_product_type: String

The type of Products allowed to be ingested into the catalog. Acceptable values are:

If this field is set to an invalid value other than these, an INVALID_ARGUMENT error is returned.

If this field is variant and merchant_center_product_id_field is itemGroupId, an INVALID_ARGUMENT error is returned.

See Product levels for more details.

merchant_center_product_id_field: String

Which field of Merchant Center Product should be imported as Product.id. Acceptable values are:

  • offerId (default): Import offerId as the product ID.
  • itemGroupId: Import itemGroupId as the product ID. Notice that Retail API will choose one item from the ones with the same itemGroupId, and use it to represent the item group.

If this field is set to an invalid value other than these, an INVALID_ARGUMENT error is returned.

If this field is itemGroupId and ingestion_product_type is variant, an INVALID_ARGUMENT error is returned.

See Product levels for more details.

Implementations

Source

impl ProductLevelConfig

pub fn new() -> Self

Creates a new default instance.

pub fn set_ingestion_product_type<T: Into<String>>(self, v: T) -> Self

Sets the value of ingestion_product_type.

Example
let x = ProductLevelConfig::new().set_ingestion_product_type("example");
pub fn set_merchant_center_product_id_field<T: Into<String>>(self, v: T) -> Self

Sets the value of merchant_center_product_id_field.

Example
let x = ProductLevelConfig::new().set_merchant_center_product_id_field("example");