#[non_exhaustive]pub struct PurgeUserEventsRequest {
pub parent: String,
pub filter: String,
pub force: bool,
/* private fields */
}Expand description
Request message for PurgeUserEvents method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The resource name of the catalog under which the events are
created. The format is
projects/${projectId}/locations/global/catalogs/${catalogId}
filter: StringRequired. The filter string to specify the events to be deleted with a length limit of 5,000 characters. Empty string filter is not allowed. The eligible fields for filtering are:
eventType: Double quoted UserEvent.event_type string.eventTime: in ISO 8601 “zulu” format.visitorId: Double quoted string. Specifying this will delete all events associated with a visitor.userId: Double quoted string. Specifying this will delete all events associated with a user.
Examples:
- Deleting all events in a time range:
eventTime > "2012-04-23T18:25:43.511Z" eventTime < "2012-04-23T18:30:43.511Z" - Deleting specific eventType in time range:
eventTime > "2012-04-23T18:25:43.511Z" eventType = "detail-page-view" - Deleting all events for a specific visitor:
visitorId = "visitor1024"
The filtering fields are assumed to have an implicit AND.
force: boolActually perform the purge.
If force is set to false, the method will return the expected purge count
without deleting any user events.
Implementations
Sourceimpl PurgeUserEventsRequest
impl PurgeUserEventsRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_filter<T: Into<String>>(self, v: T) -> Self
pub fn set_filter<T: Into<String>>(self, v: T) -> Self