#[non_exhaustive]pub struct RejoinUserEventsRequest {
pub parent: String,
pub user_event_rejoin_scope: UserEventRejoinScope,
/* private fields */
}Expand description
Request message for RejoinUserEvents method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent catalog resource name, such as
projects/1234/locations/global/catalogs/default_catalog.
user_event_rejoin_scope: UserEventRejoinScopeThe type of the user event rejoin to define the scope and range of the user
events to be rejoined with the latest product catalog. Defaults to
USER_EVENT_REJOIN_SCOPE_UNSPECIFIED if this field is not set, or set to
an invalid integer value.
Implementations
Sourceimpl RejoinUserEventsRequest
impl RejoinUserEventsRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_user_event_rejoin_scope<T: Into<UserEventRejoinScope>>(
self,
v: T,
) -> Self
pub fn set_user_event_rejoin_scope<T: Into<UserEventRejoinScope>>( self, v: T, ) -> Self
Sets the value of user_event_rejoin_scope.
Example
ⓘ
use google_cloud_retail_v2::model::rejoin_user_events_request::UserEventRejoinScope;
let x0 = RejoinUserEventsRequest::new().set_user_event_rejoin_scope(UserEventRejoinScope::JoinedEvents);
let x1 = RejoinUserEventsRequest::new().set_user_event_rejoin_scope(UserEventRejoinScope::UnjoinedEvents);Trait Implementations
Sourceimpl Clone for RejoinUserEventsRequest
impl Clone for RejoinUserEventsRequest
Sourcefn clone(&self) -> RejoinUserEventsRequest
fn clone(&self) -> RejoinUserEventsRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RejoinUserEventsRequest
impl Debug for RejoinUserEventsRequest
Sourceimpl Default for RejoinUserEventsRequest
impl Default for RejoinUserEventsRequest
Sourcefn default() -> RejoinUserEventsRequest
fn default() -> RejoinUserEventsRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for RejoinUserEventsRequest
impl Message for RejoinUserEventsRequest
Sourceimpl PartialEq for RejoinUserEventsRequest
impl PartialEq for RejoinUserEventsRequest
impl StructuralPartialEq for RejoinUserEventsRequest