#[non_exhaustive]pub struct RemoveLocalInventoriesRequest {
pub product: String,
pub place_ids: Vec<String>,
pub remove_time: Option<Timestamp>,
pub allow_missing: bool,
/* private fields */
}Expand description
Request message for ProductService.RemoveLocalInventories method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.product: StringRequired. Full resource name of Product,
such as
projects/*/locations/global/catalogs/default_catalog/branches/default_branch/products/some_product_id.
If the caller does not have permission to access the Product, regardless of whether or not it exists, a PERMISSION_DENIED error is returned.
place_ids: Vec<String>Required. A list of place IDs to have their inventory deleted. At most 3000 place IDs are allowed per request.
remove_time: Option<Timestamp>The time when the inventory deletions are issued. Used to prevent out-of-order updates and deletions on local inventory fields. If not provided, the internal system time will be used.
allow_missing: boolIf set to true, and the Product is not found, the local inventory removal request will still be processed and retained for at most 1 day and processed once the Product is created. If set to false, a NOT_FOUND error is returned if the Product is not found.
Implementations
Sourceimpl RemoveLocalInventoriesRequest
impl RemoveLocalInventoriesRequest
Sourcepub fn set_product<T: Into<String>>(self, v: T) -> Self
pub fn set_product<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_place_ids<T, V>(self, v: T) -> Self
pub fn set_place_ids<T, V>(self, v: T) -> Self
Sourcepub fn set_remove_time<T>(self, v: T) -> Self
pub fn set_remove_time<T>(self, v: T) -> Self
Sets the value of remove_time.
Example
use wkt::Timestamp;
let x = RemoveLocalInventoriesRequest::new().set_remove_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_remove_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_remove_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of remove_time.
Example
use wkt::Timestamp;
let x = RemoveLocalInventoriesRequest::new().set_or_clear_remove_time(Some(Timestamp::default()/* use setters */));
let x = RemoveLocalInventoriesRequest::new().set_or_clear_remove_time(None::<Timestamp>);Sourcepub fn set_allow_missing<T: Into<bool>>(self, v: T) -> Self
pub fn set_allow_missing<T: Into<bool>>(self, v: T) -> Self
Sets the value of allow_missing.
Example
let x = RemoveLocalInventoriesRequest::new().set_allow_missing(true);Trait Implementations
Sourceimpl Clone for RemoveLocalInventoriesRequest
impl Clone for RemoveLocalInventoriesRequest
Sourcefn clone(&self) -> RemoveLocalInventoriesRequest
fn clone(&self) -> RemoveLocalInventoriesRequest
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for RemoveLocalInventoriesRequest
impl Default for RemoveLocalInventoriesRequest
Sourcefn default() -> RemoveLocalInventoriesRequest
fn default() -> RemoveLocalInventoriesRequest
Sourceimpl PartialEq for RemoveLocalInventoriesRequest
impl PartialEq for RemoveLocalInventoriesRequest
Sourcefn eq(&self, other: &RemoveLocalInventoriesRequest) -> bool
fn eq(&self, other: &RemoveLocalInventoriesRequest) -> bool
self and other values to be equal, and is used by ==.