#[non_exhaustive]pub struct SetDefaultBranchRequest {
pub catalog: String,
pub branch_id: String,
pub note: String,
pub force: bool,
/* private fields */
}Expand description
Request message to set a specified branch as new default_branch.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.catalog: StringFull resource name of the catalog, such as
projects/*/locations/global/catalogs/default_catalog.
branch_id: StringThe final component of the resource name of a branch.
This field must be one of “0”, “1” or “2”. Otherwise, an INVALID_ARGUMENT error is returned.
If there are no sufficient active products in the targeted branch and force is not set, a FAILED_PRECONDITION error is returned.
note: StringSome note on this request, this can be retrieved by CatalogService.GetDefaultBranch before next valid default branch set occurs.
This field must be a UTF-8 encoded string with a length limit of 1,000 characters. Otherwise, an INVALID_ARGUMENT error is returned.
force: boolIf set to true, it permits switching to a branch with branch_id even if it has no sufficient active products.
Implementations
Sourceimpl SetDefaultBranchRequest
impl SetDefaultBranchRequest