SetInventoryRequest

Struct SetInventoryRequest 

#[non_exhaustive]
pub struct SetInventoryRequest { pub inventory: Option<Product>, pub set_mask: Option<FieldMask>, pub set_time: Option<Timestamp>, pub allow_missing: bool, /* private fields */ }
Request message for ProductService.SetInventory method.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
inventory: Option<Product>

Required. The inventory information to update. The allowable fields to update are:

If SetInventoryRequest.inventory.name is empty or invalid, an INVALID_ARGUMENT error is returned.

If the caller does not have permission to update the Product named in Product.name, regardless of whether or not it exists, a PERMISSION_DENIED error is returned.

If the Product to update does not have existing inventory information, the provided inventory information will be inserted.

If the Product to update has existing inventory information, the provided inventory information will be merged while respecting the last update time for each inventory field, using the provided or default value for SetInventoryRequest.set_time.

The caller can replace place IDs for a subset of fulfillment types in the following ways:

The caller can clear all place IDs from a subset of fulfillment types in the following ways:

The last update time is recorded for the following inventory fields:

If a full overwrite of inventory information while ignoring timestamps is needed, ProductService.UpdateProduct should be invoked instead.

set_mask: Option<FieldMask>

Indicates which inventory fields in the provided Product to update.

At least one field must be provided.

If an unsupported or unknown field is provided, an INVALID_ARGUMENT error is returned and the entire update will be ignored.

set_time: Option<Timestamp>

The time when the request is issued, used to prevent out-of-order updates on inventory fields with the last update time recorded. If not provided, the internal system time will be used.

allow_missing: bool

If set to true, and the Product with name Product.name is not found, the inventory update will still be processed and retained for at most 1 day until the Product is created. If set to false, a NOT_FOUND error is returned if the Product is not found.

Implementations

Source

impl SetInventoryRequest

pub fn new() -> Self

pub fn set_inventory<T>(self, v: T) -> Self
where T: Into<Product>,

Sets the value of inventory.

Example
use google_cloud_retail_v2::model::Product;
let x = SetInventoryRequest::new().set_inventory(Product::default()/* use setters */);
pub fn set_or_clear_inventory<T>(self, v: Option<T>) -> Self
where T: Into<Product>,

Sets or clears the value of inventory.

Example
use google_cloud_retail_v2::model::Product;
let x = SetInventoryRequest::new().set_or_clear_inventory(Some(Product::default()/* use setters */));
let x = SetInventoryRequest::new().set_or_clear_inventory(None::<Product>);
pub fn set_set_mask<T>(self, v: T) -> Self
where T: Into<FieldMask>,

Sets the value of set_mask.

Example
use wkt::FieldMask;
let x = SetInventoryRequest::new().set_set_mask(FieldMask::default()/* use setters */);
pub fn set_or_clear_set_mask<T>(self, v: Option<T>) -> Self
where T: Into<FieldMask>,

Sets or clears the value of set_mask.

Example
use wkt::FieldMask;
let x = SetInventoryRequest::new().set_or_clear_set_mask(Some(FieldMask::default()/* use setters */));
let x = SetInventoryRequest::new().set_or_clear_set_mask(None::<FieldMask>);
pub fn set_set_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of set_time.

Example
use wkt::Timestamp;
let x = SetInventoryRequest::new().set_set_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_set_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of set_time.

Example
use wkt::Timestamp;
let x = SetInventoryRequest::new().set_or_clear_set_time(Some(Timestamp::default()/* use setters */));
let x = SetInventoryRequest::new().set_or_clear_set_time(None::<Timestamp>);
pub fn set_allow_missing<T: Into<bool>>(self, v: T) -> Self

Sets the value of allow_missing.

Example
let x = SetInventoryRequest::new().set_allow_missing(true);