#[non_exhaustive]pub struct TuneModelRequest {
pub name: String,
/* private fields */
}Expand description
Request to manually start a tuning process now (instead of waiting for the periodically scheduled tuning to happen).
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The resource name of the model to tune.
Format:
projects/{project_number}/locations/{location_id}/catalogs/{catalog_id}/models/{model_id}
Implementations