#[non_exhaustive]pub struct UpdateCatalogRequest {
pub catalog: Option<Catalog>,
pub update_mask: Option<FieldMask>,
/* private fields */
}Expand description
Request for CatalogService.UpdateCatalog method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.catalog: Option<Catalog>Required. The Catalog to update.
If the caller does not have permission to update the Catalog, regardless of whether or not it exists, a PERMISSION_DENIED error is returned.
If the Catalog to update does not exist, a NOT_FOUND error is returned.
update_mask: Option<FieldMask>Indicates which fields in the provided Catalog to update.
If an unsupported or unknown field is provided, an INVALID_ARGUMENT error is returned.
Implementations
Sourceimpl UpdateCatalogRequest
impl UpdateCatalogRequest
Sourcepub fn set_catalog<T>(self, v: T) -> Self
pub fn set_catalog<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_catalog<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_catalog<T>(self, v: Option<T>) -> Self
Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateCatalogRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateCatalogRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateCatalogRequest::new().set_or_clear_update_mask(None::<FieldMask>);Trait Implementations
Sourceimpl Clone for UpdateCatalogRequest
impl Clone for UpdateCatalogRequest
Sourcefn clone(&self) -> UpdateCatalogRequest
fn clone(&self) -> UpdateCatalogRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdateCatalogRequest
impl Debug for UpdateCatalogRequest
Sourceimpl Default for UpdateCatalogRequest
impl Default for UpdateCatalogRequest
Sourcefn default() -> UpdateCatalogRequest
fn default() -> UpdateCatalogRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for UpdateCatalogRequest
impl Message for UpdateCatalogRequest
Sourceimpl PartialEq for UpdateCatalogRequest
impl PartialEq for UpdateCatalogRequest
impl StructuralPartialEq for UpdateCatalogRequest