#[non_exhaustive]pub struct UpdateCompletionConfigRequest {
pub completion_config: Option<CompletionConfig>,
pub update_mask: Option<FieldMask>,
/* private fields */
}Expand description
Request for CatalogService.UpdateCompletionConfig method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.completion_config: Option<CompletionConfig>Required. The CompletionConfig to update.
If the caller does not have permission to update the CompletionConfig, then a PERMISSION_DENIED error is returned.
If the CompletionConfig to update does not exist, a NOT_FOUND error is returned.
update_mask: Option<FieldMask>Indicates which fields in the provided CompletionConfig to update. The following are the only supported fields:
- CompletionConfig.matching_order
- CompletionConfig.max_suggestions
- CompletionConfig.min_prefix_length
- CompletionConfig.auto_learning
If not set, all supported fields are updated.
Implementations
Sourceimpl UpdateCompletionConfigRequest
impl UpdateCompletionConfigRequest
Sourcepub fn set_completion_config<T>(self, v: T) -> Selfwhere
T: Into<CompletionConfig>,
pub fn set_completion_config<T>(self, v: T) -> Selfwhere
T: Into<CompletionConfig>,
Sets the value of completion_config.
Example
ⓘ
use google_cloud_retail_v2::model::CompletionConfig;
let x = UpdateCompletionConfigRequest::new().set_completion_config(CompletionConfig::default()/* use setters */);Sourcepub fn set_or_clear_completion_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<CompletionConfig>,
pub fn set_or_clear_completion_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<CompletionConfig>,
Sets or clears the value of completion_config.
Example
ⓘ
use google_cloud_retail_v2::model::CompletionConfig;
let x = UpdateCompletionConfigRequest::new().set_or_clear_completion_config(Some(CompletionConfig::default()/* use setters */));
let x = UpdateCompletionConfigRequest::new().set_or_clear_completion_config(None::<CompletionConfig>);Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateCompletionConfigRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateCompletionConfigRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateCompletionConfigRequest::new().set_or_clear_update_mask(None::<FieldMask>);Trait Implementations
Sourceimpl Clone for UpdateCompletionConfigRequest
impl Clone for UpdateCompletionConfigRequest
Sourcefn clone(&self) -> UpdateCompletionConfigRequest
fn clone(&self) -> UpdateCompletionConfigRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for UpdateCompletionConfigRequest
impl Default for UpdateCompletionConfigRequest
Sourcefn default() -> UpdateCompletionConfigRequest
fn default() -> UpdateCompletionConfigRequest
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for UpdateCompletionConfigRequest
impl PartialEq for UpdateCompletionConfigRequest
Sourcefn eq(&self, other: &UpdateCompletionConfigRequest) -> bool
fn eq(&self, other: &UpdateCompletionConfigRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for UpdateCompletionConfigRequest