#[non_exhaustive]pub struct UserEventImportSummary {
pub joined_events_count: i64,
pub unjoined_events_count: i64,
/* private fields */
}Expand description
A summary of import result. The UserEventImportSummary summarizes the import status for user events.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.joined_events_count: i64Count of user events imported with complete existing catalog information.
unjoined_events_count: i64Count of user events imported, but with catalog information not found in the imported catalog.
Implementations
Sourceimpl UserEventImportSummary
impl UserEventImportSummary
Sourcepub fn set_joined_events_count<T: Into<i64>>(self, v: T) -> Self
pub fn set_joined_events_count<T: Into<i64>>(self, v: T) -> Self
Sets the value of joined_events_count.
Example
ⓘ
let x = UserEventImportSummary::new().set_joined_events_count(42);Sourcepub fn set_unjoined_events_count<T: Into<i64>>(self, v: T) -> Self
pub fn set_unjoined_events_count<T: Into<i64>>(self, v: T) -> Self
Sets the value of unjoined_events_count.
Example
ⓘ
let x = UserEventImportSummary::new().set_unjoined_events_count(42);Trait Implementations
Sourceimpl Clone for UserEventImportSummary
impl Clone for UserEventImportSummary
Sourcefn clone(&self) -> UserEventImportSummary
fn clone(&self) -> UserEventImportSummary
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UserEventImportSummary
impl Debug for UserEventImportSummary
Sourceimpl Default for UserEventImportSummary
impl Default for UserEventImportSummary
Sourcefn default() -> UserEventImportSummary
fn default() -> UserEventImportSummary
Returns the “default value” for a type. Read more
Sourceimpl Message for UserEventImportSummary
impl Message for UserEventImportSummary
Sourceimpl PartialEq for UserEventImportSummary
impl PartialEq for UserEventImportSummary
impl StructuralPartialEq for UserEventImportSummary