GenerativeQuestionService

Trait GenerativeQuestionService 

pub trait GenerativeQuestionService:
    Debug
    + Send
    + Sync {
    // Provided methods
    fn update_generative_questions_feature_config(
        &self,
        _req: UpdateGenerativeQuestionsFeatureConfigRequest,
        _options: RequestOptions,
    ) -> impl Future<Output = Result<Response<GenerativeQuestionsFeatureConfig>>> + Send { ... }
    fn get_generative_questions_feature_config(
        &self,
        _req: GetGenerativeQuestionsFeatureConfigRequest,
        _options: RequestOptions,
    ) -> impl Future<Output = Result<Response<GenerativeQuestionsFeatureConfig>>> + Send { ... }
    fn list_generative_question_configs(
        &self,
        _req: ListGenerativeQuestionConfigsRequest,
        _options: RequestOptions,
    ) -> impl Future<Output = Result<Response<ListGenerativeQuestionConfigsResponse>>> + Send { ... }
    fn update_generative_question_config(
        &self,
        _req: UpdateGenerativeQuestionConfigRequest,
        _options: RequestOptions,
    ) -> impl Future<Output = Result<Response<GenerativeQuestionConfig>>> + Send { ... }
    fn batch_update_generative_question_configs(
        &self,
        _req: BatchUpdateGenerativeQuestionConfigsRequest,
        _options: RequestOptions,
    ) -> impl Future<Output = Result<Response<BatchUpdateGenerativeQuestionConfigsResponse>>> + Send { ... }
    fn list_operations(
        &self,
        _req: ListOperationsRequest,
        _options: RequestOptions,
    ) -> impl Future<Output = Result<Response<ListOperationsResponse>>> + Send { ... }
    fn get_operation(
        &self,
        _req: GetOperationRequest,
        _options: RequestOptions,
    ) -> impl Future<Output = Result<Response<Operation>>> + Send { ... }
}
Defines the trait used to implement super::client::GenerativeQuestionService.

Application developers may need to implement this trait to mock client::GenerativeQuestionService. In other use-cases, application developers only use client::GenerativeQuestionService and need not be concerned with this trait or its implementations.

Services gain new RPCs routinely. Consequently, this trait gains new methods too. To avoid breaking applications the trait provides a default implementation of each method. Most of these implementations just return an error.

Provided Methods

fn update_generative_questions_feature_config( &self, _req: UpdateGenerativeQuestionsFeatureConfigRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<GenerativeQuestionsFeatureConfig>>> + Send

fn get_generative_questions_feature_config( &self, _req: GetGenerativeQuestionsFeatureConfigRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<GenerativeQuestionsFeatureConfig>>> + Send

fn list_generative_question_configs( &self, _req: ListGenerativeQuestionConfigsRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<ListGenerativeQuestionConfigsResponse>>> + Send

fn update_generative_question_config( &self, _req: UpdateGenerativeQuestionConfigRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<GenerativeQuestionConfig>>> + Send

fn batch_update_generative_question_configs( &self, _req: BatchUpdateGenerativeQuestionConfigsRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<BatchUpdateGenerativeQuestionConfigsResponse>>> + Send

fn list_operations( &self, _req: ListOperationsRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<ListOperationsResponse>>> + Send

fn get_operation( &self, _req: GetOperationRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<Operation>>> + Send

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors